fiss_threshold_label: Label for one threshold setting in Fiss charts and summaries

View source: R/tsqca_fiss_core.R

fiss_threshold_labelR Documentation

Label for one threshold setting in Fiss charts and summaries

Description

Label for one threshold setting in Fiss charts and summaries

Usage

fiss_threshold_label(result, thr_key, sep = "=")

Arguments

result

Sweep result augmented by compute_fiss_core().

thr_key

Character. Threshold key (a name of result$fiss_core).

sep

Character placed between the variable name and the value.

Value

"X3=6" for a ctSweepS() result sweeping X3, otherwise "thrY=6".


ThSQCA documentation built on Sept. 26, 2026, 5:07 p.m.