Get the number of intermediate solutions

get_n_solutions(sol)

Arguments

sol

A solution object returned by QCA::minimize().

Value

Integer. Number of intermediate solutions, or 0 if none.

Note

When dir.exp is specified, the true Intermediate solution is stored in sol$i.sol, not sol$solution (which contains the Parsimonious solution). See collect_unique_i_sol for why deduplication is required when multiple prime implicant charts are present.