Displays detailed results table with solution formulas and fit measures.

# S3 method for class 'tsqca_result'
summary(object, ...)

# S3 method for class 'otSweep_result'
summary(object, ...)

# S3 method for class 'dtSweep_result'
summary(object, ...)

# S3 method for class 'ctSweepS_result'
summary(object, ...)

# S3 method for class 'ctSweepM_result'
summary(object, ...)

Arguments

object

A ThSQCA result object returned by one of the sweep functions.

...

Additional arguments (ignored).

Value

Invisibly returns object.

Examples

# \donttest{
data(sample_data)
result <- otSweep(
  dat = sample_data,
  outcome = "Y",
  conditions = c("X1", "X2", "X3"),
  sweep_range = 6:8,
  thrX = c(X1 = 7, X2 = 7, X3 = 7)
)
summary(result)
#> OTS Summary
#> =========== 
#> 
#> Analysis Parameters:
#>   Outcome: Y 
#>   Conditions: X1, X2, X3 
#>   Consistency cutoff: 0.8 
#>   Frequency cutoff: 1 
#> 
#> Results by Threshold:
#> 
#>  thrY                  expression inclS  covS n_solutions
#>     6 ~X1*X3 + ~X2*X3 + X1*X2*~X3 0.906 0.853           1
#>     7 ~X1*X3 + ~X2*X3 + X1*X2*~X3 0.906 0.879           1
#>     8                 No solution    NA    NA           0
#> 
# }