R/tsqca_fiss_core.R
classify_term_conditions.RdA condition is **core** when it appears with the same presence/absence status in at least one term of the parsimonious solution. A condition is **peripheral** when it appears in the intermediate term but NOT (with the same status) in any parsimonious term.
classify_term_conditions(interm_term, parsim_map, conditions)Character. Single intermediate-solution term.
Named list returned by extract_cond_status_map()
for the parsimonious solution.
Character vector of all condition names.
Data frame with columns:
condition, status ("present"/"absent"/"dontcare"),
type ("core"/"peripheral"/"dontcare").