View source: R/tsqca_fiss_core.R
| fiss_threshold_label | R Documentation |
Label for one threshold setting in Fiss charts and summaries
fiss_threshold_label(result, thr_key, sep = "=")
result |
Sweep result augmented by |
thr_key |
Character. Threshold key (a name of |
sep |
Character placed between the variable name and the value. |
"X3=6" for a ctSweepS() result sweeping X3,
otherwise "thrY=6".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.