View source: R/tsqca_fiss_core.R
| generate_fiss_chart | R Documentation |
Produces a Markdown-formatted configuration chart following Fiss (2011), using four symbols to distinguish core conditions (conditions of the parsimonious term contained in each configuration) from peripheral conditions (present in the intermediate solution only).
generate_fiss_chart(
result,
conditions = NULL,
symbol_set = c("unicode", "ascii", "latex"),
language = c("en", "ja")
)
result |
Sweep result augmented by |
conditions |
Character vector. Condition names (row order).
If |
symbol_set |
Character. One of |
language |
Character. |
Call compute_fiss_core first to augment the sweep result.
Character string: Markdown-formatted Fiss configuration chart.
Fiss, P. C. (2011). Building better causal theories: A fuzzy set approach to typologies in organization research. Academy of Management Journal, 54(2), 393-420.
compute_fiss_core
## Not run:
data(sample_data)
res <- otSweep(
dat = sample_data, outcome = "Y",
conditions = c("X1", "X2", "X3"),
sweep_range = 6:8,
thrX = c(X1 = 7, X2 = 7, X3 = 7),
include = "?", dir.exp = c(1, 1, 1),
return_details = TRUE
)
res_fiss <- compute_fiss_core(res, conditions = c("X1", "X2", "X3"))
cat(generate_fiss_chart(res_fiss))
cat(generate_fiss_chart(res_fiss, symbol_set = "latex"))
cat(generate_fiss_chart(res_fiss, language = "ja"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.