R/tsqca_config_chart.R
generate_threshold_level_chart.RdCreates a configuration chart where each column represents one threshold, showing all conditions that appear in any configuration at that threshold.
generate_threshold_level_chart(sum_df, conditions, symbols, language = "en")Character string containing Markdown-formatted table.