View source: R/tsqca_fiss_core.R
| nested_core_conditions | R Documentation |
Implements the configuration-level reading of Fiss (2011): the core conditions of an intermediate configuration are the conditions of the parsimonious term(s) contained in it. A parsimonious term is contained (nested) in the intermediate term when every condition it specifies has the same status (present or absent) in the intermediate term. When several parsimonious terms are contained in it, their conditions are pooled, as in solution 2 of Fiss (2011, Table 4).
nested_core_conditions(interm_term, parsim_model, conditions)
interm_term |
Character. A single intermediate-solution term. |
parsim_model |
Character vector. The terms of one parsimonious minimal solution. |
conditions |
Character vector of all condition names. |
List with core (character, condition names classified as
core) and nested (logical, whether any parsimonious term is
contained in the intermediate term).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.